from omu_chat.const import IDENTIFIER

CHAT_PERMISSION_ID = IDENTIFIER
CHAT_READ_PERMISSION_ID = CHAT_PERMISSION_ID / "read"
CHAT_WRITE_PERMISSION_ID = CHAT_PERMISSION_ID / "write"
CHAT_SEND_PERMISSION_ID = CHAT_PERMISSION_ID / "send"
CHAT_CHANNEL_TREE_PERMISSION_ID = CHAT_PERMISSION_ID / "create_channel_tree"
CHAT_REACTION_PERMISSION_ID = CHAT_PERMISSION_ID / "reaction"



from __future__ import annotations

from typing import TypedDict

from omu.model import Model


class PaidJson(TypedDict):
    amount: float
    currency: str


class Paid(Model[PaidJson]):
    def __init__(self, *, amount: float, currency: str) -> None:
        self.amount = amount
        self.currency = currency

    @classmethod
    def from_json(cls, json: PaidJson) -> Paid:
        return cls(amount=json["amount"], currency=json["currency"])

    def to_json(self) -> PaidJson:
        return {"amount": self.amount, "currency": self.currency}

    def __eq__(self, other: object) -> bool:
        if not isinstance(other, Paid):
            return NotImplemented
        return self.amount == other.amount and self.currency == other.currency

    def __repr__(self) -> str:
        return f"Paid(amount={self.amount}, currency={self.currency})"
